/// <reference types="node" />
import VM from 'vm';
import ShadowRootRenderResult from '../shadow-root/ShadowRootRenderResult';
/**
 * This class is used for rendering a script server side.
 */
export default class VMContext {
    private context;
    /**
     * Returns route HTML.
     *
     * @param options Options.
     * @param options.html HTML.
     * @param [options.script] Script.
     * @param [options.url] Page URL.
     * @param [options.openShadowRoots=false] Set to "true" to open up shadow roots.
     * @param [options.extractCSS=true] Set to "true" to extract CSS when opening shadow roots.
     * @param [options.scopeCSS=true] Set to "true" to enable scoping of CSS when opening shadow roots.
     * @return HTML.
     */
    render(options: {
        html: string;
        script: VM.Script;
        url?: string;
        openShadowRoots: boolean;
        extractCSS: boolean;
        scopeCSS: boolean;
    }): Promise<ShadowRootRenderResult>;
    /**
     * Disposes the render.
     */
    dispose(): void;
    /**
     * Creates a context.
     *
     * @return Context.
     */
    private createContext;
}
